A Python implementation of American National Standard ANSI S3.5-1997
**"Methods for Calculation of the Speech Intelligibility Index"**
This code is translated from Hannes Muesch's Matlab implementation.

This package includes both Python/Numpy and Python/JAX implementations.

There is a Google Colab that demonstrates how to use this code and shows
typical results.  This colab is a good place to start:
https://colab.research.google.com/drive/1bAnDpUUx5-BYkL3l3ukNVVnsLzEhy-ds.

For more information about the speech intelligibility index (SII) please see
the Acoustical Society of America (ASA) working group's web site at
https://sii.to/index.html.

To use these scripts successfully, you might want to be familiar with the
concepts and definitions of the Speech Intelligibility Index (SII).
You can obtain a copy of the standard at the ANSI webstore
https://webstore.ansi.org/standards/asa/ansiasas31997r2017

You can reach out to the members of the Acoustical Society of America (ASA)
Working Group S3-79, which is in charge of reviewing that standard, at
https://sii.to/index.html.

